@@ -32,8 +32,14 @@ print_cta(const struct di_edid_cta *cta);
 void
 print_displayid(const struct di_displayid *displayid);
 
+void
+print_displayid2(const struct di_displayid2 *displayid2);
+
 void
 print_displayid_type_i_ii_vii_timing(const struct di_displayid_type_i_ii_vii_timing *t,
 				  int indent, const char *prefix);
 
+void
+compute_aspect_ratio(int width, int height, int *horiz_ratio, int *vert_ratio);
+
 #endif
